#!/bin/sh

import argparse

from generator import password_generator


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("-l", "--length", "-L", type=int, required=True, help="length of a password")
    parser.add_argument("-n", "--number", "-N", type=int, required=True, help="number of generated password")
    parser.add_argument("-c", "--check", "-C", action="store_true", help="check the passwords")
    parser.add_argument("-e", "--eval", "-E", action="store_true", help="eval the passwords")
    parser.add_argument("--digit", "--Digit", "--DIGIT", action="store_true", help="use digits in the generation")
    parser.add_argument("--lowercase", "--LOWERCASE", "-Lowercase", action="store_true",
                        help="use lowercase in the generation")
    parser.add_argument("--uppercase", "--UPPERCASE", "--Uppercase", action="store_true",
                        help="use uppercase in the generation")
    parser.add_argument("--symbol", "--SYMBOL", "--SYMBOL", action="store_true", help="use symbols in the generation")
    args = parser.parse_args()

    digit = False
    lowercase = False
    uppercase = False
    symbol = False
    check = False
    eval = False

    if args.digit:
        digit = True
    if args.lowercase:
        lowercase = True
    if args.uppercase:
        uppercase = True
    if args.symbol:
        symbol = True
    if args.check:
        print("PLEASE NOTE THAT")
        check = True

    if args.eval:
        eval = True

    password_generator(args.length, args.number, tocheck=check, toeval=eval, digit=digit, lowercase=lowercase, uppercase=uppercase, symbol=symbol)


if __name__ == "__main__":
    main()



import re


def password_strength(password: str) -> int:
    score = 0

    # Longueur
    if len(password) >= 8:
        score += 1
    if len(password) >= 12:
        score += 1
    if len(password) >= 16:
        score += 1

    # Complexité
    if re.search("[a-z]", password) and re.search("[A-Z]", password):
        score += 1
    if re.search("[0-9]", password):
        score += 1
    if re.search("[@#$%^&+=]", password):
        score += 1
    if re.search("[^a-zA-Z0-9@#$%^&+=]", password):
        score += 1

    # Variation
    if len(set(password)) >= 10:
        score += 1
    if len(set(password)) >= 15:
        score += 1
    if len(set(password)) >= 20:
        score += 1

    return score



import urllib3
from hasher import Keccak512


def check(password: str, test: bool = False) -> bool:
    hashed_password = Keccak512(password)
    https = urllib3.PoolManager()
    r = https.request("GET", f"https://passwords.xposedornot.com/api/v1/pass/anon/{hashed_password}")

    if r.data == b'{"Error":"Not found"}\n':
        if test:
            print("Is safe")
        return True
    else:
        return False



import string
import random as rd
from checker import check
from eval import password_strength


def password_generator(length: int, number: int,
                       tocheck: bool = False, toeval: bool = False,
                       digit: bool = False, lowercase: bool = False,
                       uppercase: bool = False, symbol: bool = False):
    """
    :param length: The length of the generated password
    :param number: The number of generated password needed
    :param tocheck: If you want to check if the generated password has been exposed via the xposedornot API
    :param toeval: If you want to simply eval the quality of your password on a scale of ten
    :param digit: If you want that your password contain digits/numbers (it can be combined with the following args)
    :param lowercase: If you want that your password contain lowercase letters
    :param uppercase: If you want that your password contain uppercase letters
    :param symbol: If you want that your password contain symbol/punctuation
    """
    char = []

    if not (digit or lowercase or uppercase or symbol):
        char = list(string.printable)[:-6]

    if digit:
        char += string.digits

    if lowercase:
        char += string.ascii_lowercase

    if uppercase:
        char += string.ascii_uppercase

    if symbol:
        char += string.punctuation

    for i in range(number):
        global password
        password = []
        password = [""] * length

        for j in range(length):
            password.append(char[rd.randint(0, len(char) - 1)])

        if tocheck and toeval:
            if check(''.join(password)):
                print(f"{i + 1}. {''.join(password)} {password_strength(str(password))}/10")

        elif tocheck:
            if check(''.join(password)):
                print(f"{i + 1}. {''.join(password)} {password_strength(str(password))}/10")

        elif toeval:
            print(f"{i + 1}. {''.join(password)} {password_strength(str(password))}/10")

        else:
            print(f"{i + 1}. {''.join(password)}")

    print(f"{i + 1} passwords were generated")
